# -*- coding: utf-8 -*-

#Copyright 2009 tv-player team <tvplayer.staff@gmail.com>
#       
#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU Lesser General Public License as published by
#the Free Software Foundation; version 3 of the License.
#       
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU Lesser General Public License for more details.
#       
#You should have received a copy of the GNU Lesser General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#MA 02110-1301, USA.

"""
Il modulo contiene tutte le strutture dati necessarie per gestire
dei player web.
"""
import os
import time
import pygst, gst
import threading, gtk, time

import gettext
_ = gettext.gettext

from subprocess import Popen

DEFAULT_USER_AGENT = "Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.1.3) Gecko/20090910 Firefox/3.5.3"

class Player() :
    """
    La classe Player rappresenta un programma "riproduttore". Serve ad impostare
    percorso del riproduttore e le varie opzioni.

    @ivar _uri : Percorso del riproduttore di file desiderato.
    @ivar _options : Parametri da dare al player.
    @ivar _user_agent : User Agent del player.
    """
    _uri = "vlc"
    _options = "--http-user-agent"
    _user_agent = DEFAULT_USER_AGENT
    
    def __init__(self, uri="vlc", options="--http-user-agent", user_agent=DEFAULT_USER_AGENT) :
        self._uri = uri
        self._options = options
        self._user_agent = user_agent
        
    def play(self, url, play_button, stop_button, gstplayer, gst_is_playing) :
        """
        Avvia la riproduzione dell'url specificato con il player attuale.
        
        @param url: Indirizzo remoto del flusso video/audio da riprodurre.
        @type url: String.
        """
        if self._uri=="totem":
            os.system("killall totem")
          #  p = Popen([self._uri, url])
            os.system(self._uri+" \""+url+"\" &")
        elif self._uri=="mplayer":
            os.system("killall mplayer")
          #  p = Popen([self._uri,"-user-agent",self._user_agent, url])
            os.system(self._uri+" -user-agent \""+self._user_agent+"\" \""+url+"\" &")
        elif self._uri=="mplayerRAI":
            os.system("killall mplayer")
          #  p = Popen(["mplayer","-user-agent",self._user_agent,"-playlist", url])
            os.system("mplayer -user-agent \""+self._user_agent+"\" -playlist \""+url+"\" &")
        elif self._uri=="vlc":
            os.system("killall vlc")
          #  p = Popen([self._uri, self._options, self._user_agent, url])
            os.system(self._uri+" "+self._options+" \""+self._user_agent+"\" \""+url+"\" &")
        elif self._uri=="integrato":
			self.play_stop(url, play_button, stop_button, gstplayer, gst_is_playing)
        else:
			os.system(self._uri+" \""+url+"\" &")
			
    def play_stop(self, data, play_button, stop_button, gstplayer, gst_is_playing):
        if gst_is_playing==False:
            gstplayer.set_property("uri", data)
            gstplayer.set_state(gst.STATE_PLAYING)
            play_button.hide()
            stop_button.show()
            gst_is_playing=True
        else:
            gst_is_playing=True
            gstplayer.set_state(gst.STATE_NULL)
            gstplayer.set_property("uri", data)
            gstplayer.set_state(gst.STATE_PLAYING)
            

       
class PlayerThread(threading.Thread):
    def __init__(self, uri, play_button, stop_button, gstplayer, gst_is_playing, statusbar, progressbar):
        threading.Thread.__init__(self)
      #  gtk.gdk.threads_init()
        self._uri=uri
        self.play_button=play_button
        self.stop_button=stop_button
        self.gstplayer=gstplayer
        self.gst_is_playing=gst_is_playing
        self.statusbar=statusbar
        self.progressbar=progressbar
        self.cont=0
        
    def timeout2(self):
        gtk.gdk.threads_enter()
        self.cont+=0.2
        self.progressbar.set_text("Buffering "+str(self.cont*100)+"%")
        self.progressbar.set_fraction(self.cont)
        gtk.gdk.threads_leave()
        
    def timeout(self):
        gtk.gdk.threads_enter()
        self.progressbar.hide()
        self.statusbar.push(1,_("Playing La7 Recordings"))
        if self.gst_is_playing==False:
            self.gstplayer.set_property("uri", self._uri)
            self.gstplayer.set_state(gst.STATE_PLAYING)
            self.play_button.hide()
            self.stop_button.show()
            self.gst_is_playing=True
        else:
            self.gst_is_playing=True
            self.gstplayer.set_state(gst.STATE_NULL)
            self.gstplayer.set_property("uri", self._uri)
            self.gstplayer.set_state(gst.STATE_PLAYING)
        gtk.gdk.threads_leave()	
    def run(self):
        self.progressbar.show()
        self.timer = threading.Timer(5, self.timeout)	
        self.timer.start()
        
        self.cont+=0.2
        self.progressbar.set_text("Buffering "+str(self.cont*100)+"%")
        self.progressbar.set_fraction(self.cont)
        
        for i in range(1,5):
		    self.progresstimer = threading.Timer(i, self.timeout2)
		    self.progresstimer.start()
